<?php
namespace Ems\portalGestor\Repository;

use Zeedhi\Framework\Controller\Crud;
use Doctrine\ORM\EntityManager;
use Doctrine\DBAL\Connection;

use Ems\portalGestor\Util\NovoCodigo;

class MinhaHistoriaRepository {
    /** @var Connection */
    protected $connection;

    public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
        $this->connection    = $entityManager->getConnection();
    }

    public function getEstadocivil($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM ESTADOCIVIL
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getCondicaoFisica($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM GPE_CONDFISPES
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getRacaPessoa($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM GPE_RACAPESSOA
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getGrauinstrucao($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM GPE_GRAUINSTR
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getPais($nrorg) {
        try {
            $sql = <<<SQL
                SELECT CDPAIS, NMPAIS
                FROM PAIS
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY NMPAIS
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getEstado(
        array $params
    ) {
        $sql = <<<SQL
            SELECT *
            FROM ESTADO
            WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                AND CDPAIS = :P_CDPAIS
            ORDER BY NMESTADO
SQL;

        $std = $this->connection->prepare($sql);
        $std->execute($params);

        $estados = $std->fetchAll();

        return $estados;
    }

    public function getMunicipio($nrorg, $cdpais, $cdestado ) {
        try {
            $sql = <<<SQL
                SELECT
                    CDMUNICIPIO,
                    INITCAP(NMMUNICIPIO) NMMUNICIPIO,
                    CDMUNICIBGE
                FROM MUNICIPIO
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                  AND IDATIVO = 'S'
                  AND (CDPAIS = :P_CDPAIS OR :P_CDPAIS IS NULL)
                  AND (SGESTADO = :P_SGESTADO OR :P_SGESTADO IS NULL)
                ORDER BY NMMUNICIPIO
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0,
                    "P_CDPAIS"                  => $cdpais,
                    "P_SGESTADO"                => $cdestado
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getConselhoRegional($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM GPE_CONSELHOREG
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getNacionalidade($nrorg) {
        try {
            $sql = <<<SQL
                SELECT NRNACIONALIDADE,
                        DSNACIONALIDADE,
                        CDRAIS,
                        CDPAIS
                FROM GPE_NACIONALIDADE
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY DSNACIONALIDADE
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getClasseEstrang($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM GPE_CLASSESTRANG
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY DSCLASSESTRANG
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getCategoriaMilitar($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM GPE_CATMILITARPE
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY NMCATMILITARPE
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getBanco($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM BANCO
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY CDBANCO
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getAgencia($nrorg, $cdbanco) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM AGENCIA
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO) AND (CDBANCO = :P_CDBANCO OR :P_CDBANCO IS NULL)
                ORDER BY CDAGENCIA
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_CDBANCO"                 => $cdbanco,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getTpContaCorrente($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM TPCONTCORR
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY NRTPCONTCORR
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getTpEndereco($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM TIPOENDERECO
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY NMTIPOENDERECO
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getLogradouro($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM LOGRADOURO
                WHERE (NRORG = :P_NRORG OR NRORG = :P_NRORG_PADRAO)
                ORDER BY DSLOGRADOURO
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg,
                    "P_NRORG_PADRAO"            => 0
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getOperadores($nrorg) {
        try {
            $sql = <<<SQL
                SELECT *
                FROM OPERADOR
                WHERE (NRORG = :P_NRORG)
SQL;
            $query = $this->entityManager->getConnection()->prepare($sql);

            $query->execute(
                array(
                    "P_NRORG"                   => $nrorg
                )
            );

            $resultQuery = $query->fetchAll();

            if (isset($resultQuery)) {
                return $resultQuery;
            } else {
                return null;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

}